@@ -14,6 +14,11 @@ class Analysis(analysis_dataset.Analysis):
             masked_dataset=masked_imaging, image_path=image_path, results=results
         )
 
+        self.visualizer.visualize_hyper_images(
+            hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
+            hyper_model_image=self.hyper_model_image,
+        )
+
         self.masked_dataset = masked_imaging
 
     @property
