@@ -1,13 +1,13 @@
 from astropy import cosmology as cosmo
 
 import autofit as af
-from autolens.pipeline import phase_tagging
+from autolens.pipeline import tagging
 from autolens.pipeline.phase import dataset
-from autolens.pipeline.phase import extensions
 from autolens.pipeline.phase.interferometer.analysis import Analysis
-from autolens.pipeline.phase.interferometer.meta_interferometer_fit import (
-    MetaInterferometerFit,
+from autolens.pipeline.phase.interferometer.meta_interferometer import (
+    MetaInterferometer,
 )
+
 from autolens.pipeline.phase.interferometer.result import Result
 
 
@@ -49,7 +49,7 @@ class PhaseInterferometer(dataset.PhaseDataset):
             The side length of the subgrid
         """
 
-        paths.phase_tag = phase_tagging.phase_tag_from_phase_settings(
+        paths.phase_tag = tagging.phase_tag_from_phase_settings(
             sub_size=sub_size,
             real_space_shape_2d=real_space_mask.shape_2d,
             real_space_pixel_scales=real_space_mask.pixel_scales,
@@ -69,7 +69,7 @@ class PhaseInterferometer(dataset.PhaseDataset):
 
         self.is_hyper_phase = False
 
-        self.meta_interferometer_fit = MetaInterferometerFit(
+        self.meta_dataset = MetaInterferometer(
             model=self.model,
             sub_size=sub_size,
             real_space_mask=real_space_mask,
@@ -119,12 +119,12 @@ class PhaseInterferometer(dataset.PhaseDataset):
         lens : Analysis
             An lens object that the non-linear optimizer calls to determine the fit of a set of values
         """
-        self.meta_interferometer_fit.model = self.model
+        self.meta_dataset.model = self.model
         modified_visibilities = self.modify_visibilities(
             visibilities=dataset.visibilities, results=results
         )
 
-        masked_interferometer = self.meta_interferometer_fit.masked_dataset_from(
+        masked_interferometer = self.meta_dataset.masked_dataset_from(
             dataset=dataset,
             mask=mask,
             positions=positions,
@@ -151,63 +151,17 @@ class PhaseInterferometer(dataset.PhaseDataset):
 
         with open(file_phase_info, "w") as phase_info:
             phase_info.write("Optimizer = {} \n".format(type(self.optimizer).__name__))
-            phase_info.write(
-                "Sub-grid size = {} \n".format(self.meta_interferometer_fit.sub_size)
-            )
+            phase_info.write("Sub-grid size = {} \n".format(self.meta_dataset.sub_size))
             phase_info.write(
                 "Primary Beam shape = {} \n".format(
-                    self.meta_interferometer_fit.primary_beam_shape_2d
+                    self.meta_dataset.primary_beam_shape_2d
                 )
             )
             phase_info.write(
                 "Positions Threshold = {} \n".format(
-                    self.meta_interferometer_fit.positions_threshold
+                    self.meta_dataset.positions_threshold
                 )
             )
             phase_info.write("Cosmology = {} \n".format(self.cosmology))
 
             phase_info.close()
-
-    def extend_with_multiple_hyper_phases(
-        self,
-        hyper_galaxy=False,
-        inversion=False,
-        include_background_sky=False,
-        include_background_noise=False,
-    ):
-        hyper_phase_classes = []
-
-        if hyper_galaxy:
-            if not include_background_sky and not include_background_noise:
-                hyper_phase_classes.append(
-                    extensions.hyper_galaxy_phase.HyperGalaxyPhase
-                )
-            elif include_background_sky and not include_background_noise:
-                hyper_phase_classes.append(
-                    extensions.hyper_galaxy_phase.HyperGalaxyBackgroundSkyPhase
-                )
-            elif not include_background_sky and include_background_noise:
-                hyper_phase_classes.append(
-                    extensions.hyper_galaxy_phase.HyperGalaxyBackgroundNoisePhase
-                )
-            else:
-                hyper_phase_classes.append(
-                    extensions.hyper_galaxy_phase.HyperGalaxyBackgroundBothPhase
-                )
-
-        if inversion:
-            if not include_background_sky and not include_background_noise:
-                hyper_phase_classes.append(extensions.InversionPhase)
-            elif include_background_sky and not include_background_noise:
-                hyper_phase_classes.append(extensions.InversionBackgroundSkyPhase)
-            elif not include_background_sky and include_background_noise:
-                hyper_phase_classes.append(extensions.InversionBackgroundNoisePhase)
-            else:
-                hyper_phase_classes.append(extensions.InversionBackgroundBothPhase)
-
-        if len(hyper_phase_classes) == 0:
-            return self
-        else:
-            return extensions.CombinedHyperPhase(
-                phase=self, hyper_phase_classes=hyper_phase_classes
-            )
