@@ -21,7 +21,7 @@ lens_galaxy = al.Galaxy(
     )
 )
 
-masked_imaging = al.masked.imaging(imaging=imaging, mask=mask)
+masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
 
 tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy])
 fit = al.fit(masked_dataset=masked_imaging, tracer=tracer)
