@@ -45,7 +45,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
         radius=radius,
     )
 
-    masked_imaging = al.masked.imaging(imaging=imaging, mask=mask)
+    masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
 
     source_galaxy = al.Galaxy(
         redshift=1.0,
