@@ -51,7 +51,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
         radius=radius,
     )
 
-    masked_imaging = al.masked.imaging(imaging=imaging, mask=mask)
+    masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
 
     print(
         "Rectangular Inversion fit run times for image type " + data_resolution + "\n"
